<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ThemeOO
 * @author ThemeOO
 */

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	die();
}

if ( ! function_exists( 'themeoo_get_custom_logo' ) ) {
	/**
	 * Returns a custom logo, linked to home unless the theme supports removing the link on the home page.
	 *
	 * @since 4.5.0
	 * @since 5.5.0 Added option to remove the link on the home page with `unlink-homepage-logo` theme support
	 *              for the `custom-logo` theme feature.
	 * @since 5.5.1 Disabled lazy-loading by default.
	 *
	 * @param int $blog_id Optional. ID of the blog in question. Default is the ID of the current blog.
	 * @return string Custom logo markup.
	 */
	function themeoo_get_custom_logo( $blog_id = 0 ) {
		$html          = '';
		$switched_blog = false;

		if ( is_multisite() && ! empty( $blog_id ) && get_current_blog_id() !== (int) $blog_id ) {
			switch_to_blog( $blog_id );
			$switched_blog = true;
		}

		$custom_logo_id = get_theme_mod( 'custom_logo' );

		$unlink_homepage_logo = (bool) get_theme_support( 'custom-logo', 'unlink-homepage-logo' );

		// We have a logo. Logo is go.
		if ( $custom_logo_id ) {

			if ( 'image/svg+xml' === get_post_mime_type( $custom_logo_id ) ) {
				$file      = get_attached_file( $custom_logo_id );
				$svg_image = file_get_contents( $file ); // phpcs:ignore WordPressVIPMinimum.Performance.FetchingRemoteData.FileGetContentsUnknown

				if ( $unlink_homepage_logo && is_front_page() && ! is_paged() ) {
					// If on the home page, don't link the logo to home.
					$html = sprintf( '<div class="logo"><span class="custom-logo-link">%1$s</span></div>', $svg_image );
				} else {
					$aria_current = is_front_page() && ! is_paged() ? ' aria-current="page"' : '';

					$html = sprintf(
						'<div class="logo"><a href="%1$s" class="custom-logo-link" rel="home"%2$s>%3$s</a></div>',
						esc_url( home_url( '/' ) ),
						$aria_current,
						$svg_image
					);
				}
			} else {
				$retina_logo_id   = get_theme_mod( 'retina_logo' );
				$custom_logo_attr = [
					'class'   => 'custom-logo normal',
					'loading' => false,
				];
				$retina_logo_attr = [
					'class'   => 'custom-logo retina',
					'loading' => false,
				];

				if ( $unlink_homepage_logo && is_front_page() && ! is_paged() ) {
					/*
					 * If on the home page, set the logo alt attribute to an empty string,
					 * as the image is decorative and doesn't need its purpose to be described.
					 */
					$custom_logo_attr['alt'] = '';
					$retina_logo_attr['alt'] = '';
				} else {
					/*
					 * If the logo alt attribute is empty, get the site title and explicitly pass it
					 * to the attributes used by wp_get_attachment_image().
					 */
					$image_alt = get_post_meta( $custom_logo_id, '_wp_attachment_image_alt', true );
					if ( empty( $image_alt ) ) {
						$custom_logo_attr['alt'] = get_bloginfo( 'name', 'display' );
						$retina_logo_attr['alt'] = get_bloginfo( 'name', 'display' );
					}
				}

				/**
				 * Filters the list of custom logo image attributes.
				 *
				 * @since 5.5.0
				 *
				 * @param array $custom_logo_attr Custom logo image attributes.
				 * @param int   $custom_logo_id   Custom logo attachment ID.
				 * @param int   $blog_id          ID of the blog to get the custom logo for.
				 */
				$custom_logo_attr = apply_filters( 'get_custom_logo_image_attributes', $custom_logo_attr, $custom_logo_id, $blog_id );
				$retina_logo_attr = apply_filters( 'get_retina_logo_image_attributes', $retina_logo_attr, $retina_logo_id, $blog_id );

				/*
				 * If the alt attribute is not empty, there's no need to explicitly pass it
				 * because wp_get_attachment_image() already adds the alt attribute.
				 */
				$image  = wp_get_attachment_image( $custom_logo_id, 'full', false, $custom_logo_attr );
				$retina = wp_get_attachment_image( $retina_logo_id, 'full', false, $retina_logo_attr );
				$image .= $retina ? $retina : wp_get_attachment_image( $custom_logo_id, 'full', false, $retina_logo_attr );

				if ( $unlink_homepage_logo && is_front_page() && ! is_paged() ) {
					// If on the home page, don't link the logo to home.
					$html = sprintf( '<div class="logo"><span class="custom-logo-link">%1$s</span></div>', $image );
				} else {
					$aria_current = is_front_page() && ! is_paged() ? ' aria-current="page"' : '';

					$html = sprintf(
						'<div class="logo"><a href="%1$s" class="custom-logo-link" rel="home"%2$s>%3$s</a></div>',
						esc_url( home_url( '/' ) ),
						$aria_current,
						$image
					);
				}
			}
		} elseif ( is_customize_preview() ) {
			// If no logo is set but we're in the Customizer, leave a placeholder (needed for the live preview).
			$html = sprintf(
				'<div class="logo" style="display:none;"><a href="%1$s" class="custom-logo-link"><img class="custom-logo" alt="" /></a></div>',
				esc_url( home_url( '/' ) )
			);
		}

		if ( $switched_blog ) {
			restore_current_blog();
		}

		/**
		 * Filters the custom logo output.
		 *
		 * @since 4.5.0
		 * @since 4.6.0 Added the `$blog_id` parameter.
		 *
		 * @param string $html    Custom logo HTML output.
		 * @param int    $blog_id ID of the blog to get the custom logo for.
		 */
		return apply_filters( 'get_custom_logo', $html, $blog_id );
	}
}

if ( ! function_exists( 'themeoo_site_branding' ) ) :

	/**
	 * Site Branding (Logo)
	 *
	 * @return void
	 */
	function themeoo_site_branding() {
		$logo         = themeoo_get_custom_logo();
		$description  = get_bloginfo( 'description', 'display' );
		$blog_info    = get_bloginfo( 'name' );
		$hide_title   = themeoo_get_mod( 'title_tagline_hide_title' );
		$header_class = ! $hide_title ? 'site-title' : 'screen-reader-text';
		$is_home      = ( is_front_page() || is_home() ) && ! is_page();

		$mobile_grid = themeoo_get_mod( 'layout_header_menu_mobileshow' );

		switch ( $mobile_grid ) {
			case 'sm':
				$mobile_grid = 'hide-sm';
				break;
			case 'md':
				$mobile_grid = 'hide-md';
				break;
			case 'lg':
				$mobile_grid = 'hide-lg';
				break;
			case 'xl':
				$mobile_grid = 'hide-xl';
				break;
			default:
				$mobile_grid = '';
		}

		?>
		<div class="site-branding <?php echo esc_attr( $mobile_grid ); ?>">
			<?php if ( $logo ) { ?>
				<?php echo $logo; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<?php }
			if ( $blog_info ) { ?>
				<?php if ( is_front_page() && ! is_paged() ) { ?>
					<h1 class="<?php echo esc_attr( $header_class ); ?>"><?php echo esc_html( $blog_info ); ?></h1>
				<?php } elseif ( is_front_page() || is_home() ) { ?>
					<h1 class="<?php echo esc_attr( $header_class ); ?>">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( $blog_info ); ?></a>
					</h1>
				<?php } else { ?>
					<p class="<?php echo esc_attr( $header_class ); ?> faux-heading">
						<a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo esc_html( $blog_info ); ?></a>
					</p>
				<?php } ?>
			<?php }
			if ( $description && ! themeoo_get_mod( 'title_tagline_hide_tagline' ) ) { ?>
				<span class="site-description"><?php echo $description; // phpcs:ignore WordPress.Security.EscapeOutput ?></span>
			<?php } ?>
		</div><!-- .site-branding -->
		<?php
	}

endif;

if ( ! function_exists( 'themeoo_post_meta' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time, author & comments.
	 *
	 * @return void
	 */
	function themeoo_post_meta() {
		?>
		<time class="post-date updated"><i class="ti-alarm-clock"></i><?php the_time( get_option( 'date_format' ) ); ?></time>
		<span class="separator">/</span>
		<?php

		$post_title = get_the_title();
		$number     = get_comments_number();
		comments_popup_link(
			/* translators: %s: Post title. */
			sprintf( __( '<i class="ti-comment-alt"></i>&nbsp; No Comments<span class="sr-only"> on “%s”</span>', 'ayyash' ), $post_title ),
			/* translators: %s: Post title. */
			sprintf( __( '<i class="ti-comment-alt"></i>&nbsp; 1 Comment<span class="sr-only"> on “%s”</span>', 'ayyash' ), $post_title ),
			/* translators: %s: Post title. */
			sprintf( __( '<i class="ti-comment-alt"></i>&nbsp; %% Comments<span class="screen-reader-text"> on “%s”</span>', 'ayyash' ), $post_title ),
			'post-comment-stat'
		);
	}
endif;

if ( ! function_exists( 'themeoo_posted_on' ) ) :


	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 *
	 * @return void
	 */
	function themeoo_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		// @phpstan-ignore-next-line
		$time_string = sprintf( $time_string, esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ), esc_attr( get_the_modified_date( 'c' ) ), esc_html( get_the_modified_date() ) );
		?>
		<span class="posted-on">
			<?php
			printf(
				/* translators: %s: Post Created Time (with permalink to the post) */
				esc_html_x( 'Posted on %s', 'post date', 'ayyash' ),
				// @phpstan-ignore-next-line
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>' // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			);
			?>
		</span>
		<span class="byline">
			<?php
			printf(
				/* translators: %s: Post Author Name (linked to author page). */
				esc_html_x( 'by %s', 'post author', 'ayyash' ),
				// @phpstan-ignore-next-line
				'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);
			?>
		</span>
		<?php

	}
endif;

if ( ! function_exists( 'themeoo_post_read_more' ) ) :


	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 *
	 * @return void
	 */
	function themeoo_post_read_more() {
		?>
		<div class="read-more">
			<a href="<?php the_permalink(); ?>">
				<span><?php esc_html_e( 'Read More', 'ayyash' ); ?></span>
				<i class="ti-angle-double-right"></i>
			</a>
		</div>
		<?php

	}
endif;

if ( ! function_exists( 'themeoo_categorized_blog' ) ) :
	/**
	 * Returns true if a blog has more than 1 category.
	 *
	 * @return bool
	 */
	function themeoo_categorized_blog() {
		$all_the_cool_cats = get_transient( 'themeoo_category_count' );
		if ( false === $all_the_cool_cats ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories(
				[
					'fields'     => 'ids',
					'hide_empty' => 1, // We only need to know if there is more than one category.
					'number'     => 2,
				]
			);

			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );

			set_transient( 'themeoo_category_count', $all_the_cool_cats );
		}

		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so themeoo_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so themeoo_categorized_blog should return false.
			return false;
		}
	}
endif;

if ( ! function_exists( 'themeoo_post_taxonomy' ) ) :

	/**
	 * Shim for `themeoo_post_taxonomy()`.
	 *
	 * Display category, tag, or term description.
	 *
	 * @param string $view view.
	 *
	 * @return void
	 */
	function themeoo_post_taxonomy( $view ) {
		// Categories.
		if ( themeoo_get_mod( 'layout_' . $view . '_meta-cats' ) ) :
			echo get_the_category_list(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;

		// Tags.
		if ( themeoo_get_mod( 'layout_' . $view . '_meta-tags' ) ) :
			// Replicates category output.
			// @phpstan-ignore-next-line
			echo get_the_tag_list( '<ul class="post-tags"><li>', "</li>\n<li>", '</li></ul>' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;
	}
endif;

if ( ! function_exists( 'themeoo_post_single_navigation' ) ) :

	/**
	 * Shim for `the_archive_description()`.
	 *
	 * Display category, tag, or term description.
	 *
	 * @return void
	 */
	function themeoo_post_single_navigation() {
		?>
		<div class="pagination post-pagination row">
			<div class="previous col-md-6 col-sm-6"><?php previous_post_link( '%link', '<i class="ti-angle-left"></i><div class="text">' . esc_html__( 'Previous Article', 'ayyash' ) . '</div>' ); ?></div>
			<div class="next col-md-6 col-sm-6"><?php next_post_link( '%link', '<i class="ti-angle-right"></i><div class="text">' . esc_html__( 'Next Article', 'ayyash' ) . '</div>' ); ?></div>
		</div>
		<?php
	}
endif;

if ( ! function_exists( 'themeoo_post_author_info' ) ) :


	/**
	 * Shim for `themeoo_post_author_info()`.
	 *
	 * Display category, tag, or term description.
	 *
	 * @return void
	 */
	function themeoo_post_author_info() {
		$description = get_the_author_meta( 'description' );

		if ( ! post_type_supports( get_post_type(), 'author' ) ) { // @phpstan-ignore-line
			return;
		}

		$has_avatar = get_option( 'show_avatars' );

		$classes = 'row author-bio';
		if ( $has_avatar ) {
			$classes .= ' show-avatars';
		}
		if ( $description ) {
			$classes .= ' has-description';
		}

		$classes .= ' mb-4';

		?>
		<div id="about-author" class="<?php echo $classes; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>">
			<?php if ( ! $description ) { ?>
				<span class="byline">
					<?php
					printf(
						/* translators: 1: Author avatar 2: Author name. */
						esc_html__( 'by %1$s %2$s', 'ayyash' ),
						get_avatar( get_the_author_meta( 'email' ), 20, '', get_the_author() ), // @phpstan-ignore-line
						get_the_author_posts_link() // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					);
					?>
				</span>
			<?php } else { ?>
				<h2 class="author-title col-12">
					<?php
					printf(
						/* translators: %s: Author name. */
						esc_html__( 'by %s', 'ayyash' ),
						get_the_author()
					);
					?>
				</h2>
				<?php
				if ( $has_avatar ) {
					?>
					<div class="avatar-wrap justify-content-center align-items-start d-flex <?php echo $description ? 'col-sm-3 col-md-2 col-12' : 'col-12';  // @phpstan-ignore-line ?>">
						<?php echo get_avatar( get_the_author_meta( 'email' ), 90, '', get_the_author() ); // @phpstan-ignore-line ?>
					</div>
					<?php
				}
			}

			if ( $description ) {
				?>
				<div class="author-content <?php echo $has_avatar ? 'col-sm-9 col-md-10 col-12' : 'col-12'; ?>">
					<p class="author-description"><?php the_author_meta( 'description' ); ?></p><!-- .author-description -->
					<?php
					printf(
						'<a class="author-link" href="%1$s" rel="author">%2$s</a>',
						esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), // @phpstan-ignore-line
						sprintf(
							/* translators: %s: Author name. */
							esc_html__( 'View all of %s\'s posts.', 'ayyash' ),
							get_the_author()
						)
					);
					?>
				</div>
			<?php } ?>
		</div>
		<?php
	}

endif;

if ( ! function_exists( 'themeoo_try_sidebar' ) ) :


	/**
	 * Displays sidebar if the @position matches the @view sidebar position
	 *
	 * @param string $view view.
	 * @param string $position position.
	 *
	 * @return void
	 */
	function themeoo_try_sidebar( $view, $position ) {
		/**
		 * @var string $single_sidebar
		 */
		$single_sidebar  = themeoo_get_post_layout_options( 'sidebar' );
		$sidebar_grid    = themeoo_get_mod( 'layout_global_sidebar_grid' );
		$sidebar_classes = 'widget-area main-sidebar col-md-' . $sidebar_grid;
		$_position       = themeoo_get_sidebar_position( $view );
		$sidebar_classes = apply_filters( 'themeoo_sidebar_classes', $sidebar_classes, $position, $view );

		if ( $_position === $position ) {
			if ( 'default' !== $single_sidebar ) {
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} elseif ( class_exists( 'WooCommerce' ) && is_post_type_archive( 'product' ) ) {
				$woocommerce_shop_archive_sidebar = themeoo_get_mod( 'woocommerce_shop_archive_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_shop_archive_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_shop_archive_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
			} elseif ( class_exists( 'WooCommerce' ) && is_product() ) {
				$woocommerce_single_sidebar = themeoo_get_mod( 'woocommerce_single_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_single_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_single_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} elseif ( class_exists( 'WooCommerce' ) && is_cart() ) {
				$woocommerce_cart_sidebar = themeoo_get_mod( 'woocommerce_cart_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_cart_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_cart_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} elseif ( class_exists( 'WooCommerce' ) && is_checkout() ) {
				$woocommerce_checkout_sidebar = themeoo_get_mod( 'woocommerce_checkout_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_checkout_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_checkout_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} elseif ( class_exists( 'WooCommerce' ) && is_account_page() ) {
				$woocommerce_myaccount_sidebar = themeoo_get_mod( 'woocommerce_myaccount_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_myaccount_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_myaccount_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} elseif ( class_exists( 'WooCommerce' ) && is_product_category() ) {
				$woocommerce_product_catalog_sidebar = themeoo_get_mod( 'woocommerce_product_catalog_sidebar' );
				if ( themeoo_is_not_default_val( $woocommerce_product_catalog_sidebar ) ) {
					?>
					<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
						<?php dynamic_sidebar( $woocommerce_product_catalog_sidebar ); ?>
					</div><!-- #secondary -->
					<?php
				} else {
					get_sidebar();
				}
				?>
				<div id="secondary" class="<?php echo esc_attr( $sidebar_classes ); ?>" role="complementary">
					<?php dynamic_sidebar( $single_sidebar ); ?>
				</div><!-- #secondary -->
				<?php
			} else {
				// Default ..
				get_sidebar();
			}
		} else {
			// Remove WC Sidebars if requested position not matched with stored settings.
			if ( class_exists( 'WooCommerce', false ) ) {
				if ( is_post_type_archive( 'product' ) || is_product_taxonomy() || is_account_page() || is_checkout() || is_cart() ) {
					remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar' );
				} elseif ( is_product() ) {
					remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar' );
				}
			}
		}
	}

endif;

if ( ! function_exists( 'themeoo_get_content_class' ) ) {
	/**
	 * Displays the class names for the main content element.
	 *
	 * @param string|string[] $class Space-separated string or array of class names to add to the class list.
	 *
	 * @return void
	 */
	function themeoo_get_content_class( $class = '' ) {

		$classes = array(
			'themeoo-row',
			'site-content',
		);

		$section_height = (int) themeoo_get_post_layout_options( 'section_height' );

		if ( 1 === $section_height ) {
			$classes[] = 'pt-0';
		} elseif ( 2 === $section_height ) {
			$classes[] = 'pb-0';
		} elseif ( 3 === $section_height ) {
			$classes[] = 'pt-0 pb-0';
		}

		list( $classes, $class ) = themeoo_class_attribute_helper( $classes, $class );

		/**
		 * Filters the list of CSS content wrapper class names for the current post or page.
		 *
		 * @param string[] $classes An array of body class names.
		 * @param string[] $class   An array of additional class names added to the body.
		 */
		$classes = apply_filters( 'themeoo_content_class', $classes, $class );

		$classes = array_unique( $classes );

		// Separates class names with a single space, collates class names for body element.
		echo 'class="' . esc_attr( implode( ' ', $classes ) ) . '"';
	}
}

if ( ! function_exists( 'themeoo_get_footer_container_class' ) ) {
	/**
	 * Displays the class names for the main content element.
	 *
	 * @param string|string[] $class Space-separated string or array of class names to add to the class list.
	 *
	 * @return void
	 */
	function themeoo_get_footer_container_class( $class = '' ) {

		$classes = array( themeoo_get_mod( 'layout_global_content_layout' ) );

		list( $classes, $class ) = themeoo_class_attribute_helper( $classes, $class );

		/**
		 * Filters the list of CSS footer container wrapper class names for the current post or page.
		 *
		 * @param string[] $classes An array of body class names.
		 * @param string[] $class   An array of additional class names added to the body.
		 */
		$classes = apply_filters( 'themeoo_footer_container_class', $classes, $class );

		$classes = array_unique( $classes );

		// Separates class names with a single space, collates class names for body element.
		echo 'class="' . esc_attr( implode( ' ', $classes ) ) . '"';
	}
}

if ( ! function_exists( 'themeoo_main_class' ) ) :

	/**
	 * Prints the appropriate Bootstrap class for the main content area
	 *
	 * @param string|string[] $class Space-separated string or array of class names to add to the class list.
	 *
	 * @return void
	 */
	function themeoo_main_class( $class = '' ) {

		$content_grid = themeoo_get_mod( 'layout_global_content_grid' );
		$position     = themeoo_get_sidebar_position();
		$classes      = array( 'content-area' );

		if ( 'none' === $position ) {
			$classes[] = 'col-md-12';
		} else {

			if ( $content_grid < 1 || $content_grid > 12 ) {
				$content_grid = themeoo_get_default( 'layout_global_content_grid' );
			}

			$classes[] = 'col-md-' . absint( $content_grid );
		}

		list( $classes, $class ) = themeoo_class_attribute_helper( $classes, $class );

		/**
		 * Filters the list of CSS main (primary div) names for the current post or page.
		 *
		 * @param string[] $classes An array of body class names.
		 * @param string[] $class   An array of additional class names added to the body.
		 */
		$classes = apply_filters( 'themeoo_main_class', $classes, $class );

		$classes = array_unique( $classes );

		// Separates class names with a single space, collates class names for body element.
		echo 'class="' . esc_attr( implode( ' ', $classes ) ) . '"';
	}

endif;

if ( ! function_exists( 'themeoo_title_bar' ) ) :

	/**
	 * Prints the Title Bar Container
	 *
	 * @param string $view view.
	 *
	 * @return void
	 */
	function themeoo_title_bar( $view ) {
		$title_bar        = (int) themeoo_get_mod( 'layout_' . $view . '_title-bar' );
		$single_title_bar = themeoo_get_post_layout_options( 'titlebar' );
		$container_class  = apply_filters( 'themeoo_content_container_class', themeoo_get_mod( 'layout_global_content_layout' ) );
		$has_wc           = class_exists( 'WooCommerce', false );

		if ( $has_wc && is_post_type_archive( 'product' ) ) {
			$maye_show_titlebar = themeoo_get_mod( 'woocommerce_shop_archive_title-bar' );
		} elseif ( $has_wc && is_cart() ) {
			$maye_show_titlebar = ( 1 === (int) themeoo_get_mod( 'woocommerce_cart_title-bar' ) && ( 'default' === $single_title_bar ) || 'enable' === $single_title_bar );
		} elseif ( $has_wc && is_checkout() ) {
			$maye_show_titlebar = ( 1 === (int) themeoo_get_mod( 'woocommerce_checkout_title-bar' ) && ( 'default' === $single_title_bar ) || 'enable' === $single_title_bar );
		} elseif ( $has_wc && is_account_page() ) {
			$maye_show_titlebar = ( 1 === (int) themeoo_get_mod( 'woocommerce_myaccount_title-bar' ) && ( 'default' === $single_title_bar ) || 'enable' === $single_title_bar );
		} elseif ( $has_wc && is_product_category() ) {
			$maye_show_titlebar = (int) themeoo_get_mod( 'woocommerce_product_catalog_title-bar' ) === 1;
		} elseif ( is_front_page() == true ) {
			$maye_show_titlebar = ( 'default' === $single_title_bar ) || 'enable' === $single_title_bar;
		} elseif ( is_home() ) {
			$maye_show_titlebar = 1 === $title_bar;
		} else {
			$maye_show_titlebar = ( $title_bar && 'default' === $single_title_bar ) || 'enable' === $single_title_bar;
		}

		if ( apply_filters( 'themeoo_show_title_bar', $maye_show_titlebar ) ) {
			?>
			<div class="themeoo-row themeoo-title-bar" id="title-container">
				<div class="<?php echo esc_attr( $container_class ); ?> title-container">
					<div class="row">
						<div class="col-md-6"><h3><?php themeoo_page_title(); ?></h3></div>
						<div class="col-md-6"><?php themeoo_breadcrumb(); ?></div>
					</div>
				</div>
			</div>
			<?php
		}
	}

endif;

if ( ! function_exists( 'themeoo_page_title' ) ) :


	/**
	 * Prints the Page Title inside the Title Container
	 *
	 * @return void
	 */
	function themeoo_page_title() {
		if ( ( function_exists( 'is_woocommerce' ) && is_woocommerce() && is_product() ) || ( function_exists( 'is_bbpress' ) && is_bbpress() ) ) { // @phpstan-ignore-line
			the_title();
		} elseif ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
			woocommerce_page_title();
		} elseif ( is_archive() ) {
			the_archive_title();
		} elseif ( is_home() ) {
			bloginfo( 'name' );
		} elseif ( is_search() ) {
			printf(
				/* translators: %s: Current Search Term */
				esc_html__( 'Search results for: %s', 'ayyash' ),
				get_search_query()
			);
		} else {
			the_title();
		}
	}

endif;

if ( ! function_exists( 'themeoo_comments' ) ) :
	/**
	 * Prints the Comments for a page or post
	 *
	 * @param WP_Comment $comment comment.
	 * @param array $args argument.
	 * @param int $depth depth.
	 *
	 * @return void
	 */
	function themeoo_comments( $comment, $args, $depth ) {
		if ( in_array( get_comment_type(), [ 'pingback', 'trackback' ], true ) ) {
			?>
			<li class="pingback" id="comment-<?php comment_ID(); ?>">
				<article <?php comment_class( 'clearfix' ); ?>>
					<div class="comment-meta">
						<?php esc_html_e( 'Pingback:', 'ayyash' ); ?>
						<?php edit_comment_link( '<i class="ti-pencil-alt" aria-hidden="true"></i>' . __( 'Edit', 'ayyash' ), '<span class="edit-link">', '</span>' ); ?>
					</div>
					<div class="comment-content">
						<?php comment_author_link(); ?>
					</div>
				</article>
			</li>
			<?php
		} elseif ( get_comment_type() === 'comment' ) {
			$reply_link_args = array_merge(
				$args,
				[
					'depth'      => $depth,
					'max_depth'  => $args['max_depth'],
					'reply_text' => '<i class="ti-back-right" aria-hidden="true"></i>' . esc_html__( 'Reply', 'ayyash' ),
					'login_text' => '<i class="ti-back-right" aria-hidden="true"></i>' . esc_html__( 'Log in to Reply', 'ayyash' ),
				]
			);
			?>
			<li id="comment-<?php comment_ID(); ?>">
				<article <?php comment_class( 'clearfix' ); ?>>
					<div class="avatar"><?php echo get_avatar( $comment, 70 ); ?></div>
					<div class="comment-meta">
						<?php
						$author_url = get_comment_author_url();
						if ( empty( $author_url ) || false !== strpos( $author_url, 'http' ) ) {
							?>
							<i class="ti-user" aria-hidden="true"></i>
							<span class="comment-author"><?php comment_author(); ?></span>
						<?php } else { ?>
							<i class="ti-user" aria-hidden="true"></i>
							<a class="comment-author" href="<?php echo esc_url( $author_url ); ?>"><?php comment_author(); ?></a>
						<?php } ?>
						<span class="comment-date post-date"><i class="ti-time" aria-hidden="true"></i><?php comment_date(); ?> <?php esc_html_e( 'at', 'ayyash' ); ?> <?php comment_time(); ?></span>
						<span class="comment-reply"><?php comment_reply_link( $reply_link_args ); ?></span>
						<?php edit_comment_link( '<i class="ti-pencil-alt" aria-hidden="true"></i>' . esc_html__( 'Edit', 'ayyash' ), '<span class="edit-link">', '</span>' ); ?>
					</div>
					<div class="comment-content">
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<p><?php esc_html_e( 'Your comment is awaiting moderation', 'ayyash' ); ?></p>
						<?php endif; ?>
						<?php comment_text(); ?>
					</div>
				</article>
			</li>
			<?php
		}
	}
endif;

if ( ! function_exists( 'themeoo_pagination' ) ) :


	/**
	 * Prints pagination HTML required by the theme
	 *
	 * @param string|array $args Optional. Array or string of arguments for generating paginated links for archives.
	 *
	 * @see paginate_links() for detailed arguments
	 *
	 * @return void
	 */
	function themeoo_pagination( $args = '' ) {
		$args = wp_parse_args(
			$args,
			[
				'prev_text' => '<i class="ti-angle-left" aria-hidden="true"></i><span class="sr-only">' . esc_html__( 'Previous', 'ayyash' ) . '</span>',
				'next_text' => '<i class="ti-angle-right" aria-hidden="true"></i><span class="sr-only">' . esc_html__( 'Next', 'ayyash' ) . '</span>',
			]
		);

		// We need it to be array, always...
		$args['type'] = 'array';

		// Generate the pagination links;
		$pages = paginate_links( $args );

		if ( is_array( $pages ) ) {
			?>
			<div class="themeoo-pagination center">
				<ul class="pagination page-numbers">
					<?php echo '<li>' . implode( '</li><li>', $pages ) . '</li>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
				</ul>
			</div>
			<?php
		}
	}
endif;

if ( ! function_exists( 'themeoo_breadcrumb' ) ) :


	/**
	 * Prints breadcrumb HTML required by the theme
	 *
	 * @return void
	 */
	function themeoo_breadcrumb() {
		global $post;

		if ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
			woocommerce_breadcrumb(
				array(
					'wrap_before' => '<ul class="breadcrumbs">',
					'wrap_after'  => '</ul>',
					'delimiter'   => '',
					'before'      => '<li>',
					'after'       => '</li>',
				)
			);

			return;
		}

		echo '<ul class="breadcrumbs">';
		// @phpstan-ignore-next-line
		if ( function_exists( 'is_bbpress' ) && function_exists( 'bbp_breadcrumb' ) && is_bbpress() ) {
			// @phpstan-ignore-next-line
			bbp_breadcrumb(
				[
					'delimiter' => '',
					'before'    => '<li>',
					'after'     => '</li>',
				]
			);
			echo '</ul>';

			return;
		}

		// @TODO Add Yoast SEO (WP-SEO) Breadcrumbs Support.

		if ( ! is_front_page() ) {
			echo '<li><a href="' . esc_url( home_url() ) . '">' . esc_html__( 'Home', 'ayyash' ) . '</a></li>';
		}

		if ( ( ! is_tag() && is_tax() ) || is_category() || is_single() && ! is_singular( 'portfolio' ) ) {
			if ( ( ! is_tag() && is_tax() ) || is_category() ) {
				$category = array( get_queried_object() );
			} else {
				$category = get_the_category();
			}
			if ( isset( $category[0] ) && is_a( $category[0], 'WP_Term' ) ) {
				$categories = get_category_parents( $category[0]->term_id, true, '-|-' );
				if ( ! is_wp_error( $categories ) ) {
					// split into array of string.
					$categories = explode( '-|-', $categories );
					$categories = array_filter( $categories );
					if ( ! empty( $categories ) ) {
						/** @noinspection PhpParamsInspection */
						echo '<li>' . implode( '</li><li>', $categories ) . '</li>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					}
				}
			}
		}

		if ( $post && is_singular( 'portfolio' ) ) {
			// @phpstan-ignore-next-line
			echo get_the_term_list( $post->ID, 'portfolio_category', '<li>', ' - ', '</li>' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}

		if ( is_home() ) {
			echo '<li>' . esc_html( get_option( 'blog_title', __( 'Blog', 'ayyash' ) ) ) . '</li>';
		}

		if ( is_single() || is_page() ) {
			?>
			<li><?php the_title(); ?></li>
			<?php
		}

		if ( is_tag() ) {
			?>
			<li>
				<?php
				printf(
					/* translators: %s: Tag Name for breadcrumbs */
					esc_html__( 'Tag: %s', 'ayyash' ), // @phpstan-ignore-next-line
					single_tag_title( '', false )
				);
				?>
			</li>
			<?php
		}

		if ( is_404() ) {
			echo '<li>' . esc_html__( '404 - Page not Found', 'ayyash' ) . '</li>';
		}

		if ( is_search() ) {
			echo '<li>' . esc_html__( 'Search', 'ayyash' ) . '</li>';
		}

		if ( is_year() ) {
			echo '<li>' . esc_html( get_the_date( _x( 'Y', 'yearly archives date format', 'ayyash' ) ) ) . '</li>'; // @phpstan-ignore-line
		}

		echo '</ul>';
	}

endif;
/**
 * @return bool
 */
function themeoo_has_social_icons() {
	return themeoo_get_mod( 'layout_footer_social' ) && ! empty( themeoo_get_mod( 'social_profiles' ) );
}

if ( ! function_exists( 'themeoo_footer_social_icons' ) ) :
	/**
	 * Prints Footer Social Icons HTML markup
	 *
	 * @return void
	 */
	function themeoo_footer_social_icons() {
		themeoo_header_social_icons();
	}
endif;

if ( ! function_exists( 'themeoo_header_social_icons' ) ) :
	/**
	 * Prints Header Social Icons HTML markup
	 *
	 * @return void
	 */
	function themeoo_header_social_icons() {

		$profiles = (array) themeoo_get_mod( 'social_profiles' );
		$defaults = array(
			'label' => '',
			'url'   => '',
			'icon'  => '',
		);

		foreach ( $profiles as $profile ) {
			$profile = wp_parse_args( $profile, $defaults );
			if ( ! $profile['label'] || ! $profile['url'] || ! $profile['icon'] ) {
				continue;
			}

			$attributes = '';
			// don't open hash tag, tel or mailto in new tab.
			if ( false !== strpos( $profile['url'], 'http' ) ) {
				$attributes .= ' rel="noopener"';
				$attributes .= ' target="_blank"';
			}
			/** @noinspection HtmlUnknownTarget */
			/** @noinspection HtmlUnknownAttribute */
			printf(
				'<li><a data-bs-toggle="tooltip" data-bs-placement="bottom" title="%1$s" data-original-title="%1$s" class="social-icon" href="%2$s" %4$s><i class="%3$s" aria-hidden="false"></i><span class="sr-only">%1$s</span></a></li>',
				esc_attr( $profile['label'] ),
				esc_url( $profile['url'] ),
				esc_attr( $profile['icon'] ),
				esc_attr( $attributes )
			);
		}
	}
endif;

if ( ! function_exists( 'themeoo_second_header_icons' ) ) :

	/**
	 * Prints markup for Secondary Header Social icons
	 *
	 * @return void
	 */
	function themeoo_second_header_icons() {
		?>
		<div class="social-icon-container col-md-6">
			<ul>
				<?php themeoo_header_social_icons(); ?>
			</ul>
		</div>
		<!-- .social-icon-container -->
		<?php
	}
endif;

if ( ! function_exists( 'themeoo_second_header_callout' ) ) :

	/**
	 * Prints markup for Secondary Header Callout text
	 *
	 * @return void
	 */
	function themeoo_second_header_callout() {
		?>
		<div class="callout col-md-6">
			<p><?php echo wp_kses_post( themeoo_get_mod( 'layout_header_callout' ) ); ?></p>
		</div>
		<!-- .callout -->
		<?php
	}
endif;

if ( ! function_exists( 'themeoo_second_header_search' ) ) :

	/**
	 * Prints markup for Secondary Header Search
	 *
	 * @return void
	 */
	function themeoo_second_header_search() {
		?>
		<div class="search-form col-md-6">
			<?php get_search_form(); ?>
		</div>
		<!-- .search-form -->
		<?php
	}
endif;

if ( ! function_exists( 'themeoo_second_header' ) ) :

	/**
	 * Prints markup for Secondary Header
	 *
	 * @return void
	 */
	function themeoo_second_header() {
		$secondary_layout = explode( '_', themeoo_get_mod( 'layout_header_secondary_layout' ) );
		if ( count( $secondary_layout ) !== 2 ) {
			return;
		}
		foreach ( $secondary_layout as $item ) {
			$callback = "themeoo_second_header_$item";
			if ( function_exists( $callback ) && is_callable( $callback ) ) {
				call_user_func( $callback );
			}
		}
	}
endif;

if ( ! function_exists( 'themeoo_featured_image_width' ) ) :

	/**
	 * Prints CSS width style for featured image
	 *
	 * @param string $view
	 * @param WP_Post|int $post
	 *
	 * @return string
	 */
	function themeoo_featured_image_width( $view, $post = null ) {
		$post  = get_post( $post );
		$width = '';

		if ( $post && ! themeoo_get_mod( 'layout_' . $view . '_ft-img-enlarge' ) && ! themeoo_get_mod( 'layout_' . $view . '_ft-img-hide' ) && has_post_thumbnail() ) {
			$thumb_id    = get_post_thumbnail_id( $post->ID );
			$thumb_sizes = $thumb_id ? wp_get_attachment_metadata( $thumb_id, true ) : false;
			if ( $thumb_sizes ) {
				$width = floatval( $thumb_sizes['width'] );
				$width = $width >= 1140 ? 1140 : $width;
				$width = "width:{$width}px;max-width:100%";
			}
		}

		return $width;
	}
endif;

if ( ! function_exists( 'themeoo_the_title' ) ) {
	/**
	 * Display Post Title.
	 *
	 * @return void
	 */
	function themeoo_the_title() {
		$themeoo_page_title = themeoo_get_post_layout_options( 'page_title' );
		$themeoo_view       = themeoo_get_current_screen();
		$show_title         = 'enable' === $themeoo_page_title || ( 'default' === $themeoo_page_title && (int) themeoo_get_mod( 'layout_' . $themeoo_view . '_title' ) );

		if ( apply_filters( 'themeoo_show_page_title', $show_title ) ) {
			?>
			<h3 class="post-title entry-title"><a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a></h3>
			<?php
		}
	}
}

if ( ! function_exists( 'themeoo_the_post_thumbnail' ) ) {
	/**
	 * Renders the post thumbnail.
	 *
	 * @param string|int[] $size Optional. Image size. Accepts any registered image size name, or an array of
	 *                           width and height values in pixels (in that order). Default 'post-thumbnail'.
	 * @param string|array $attr Optional. Query string or array of attributes. Default empty.
	 * @param int|WP_Post  $post Optional. Default Current Post.
	 *
	 * @return void
	 */
	function themeoo_the_post_thumbnail( $size = 'post-thumbnail', $attr = '', $post = null ) {

		$themeoo_view = themeoo_get_current_screen();

		if ( themeoo_get_mod( 'layout_' . $themeoo_view . '_ft-img-hide' ) ) {
			return;
		}

		$themeoo_layout = themeoo_get_content_layout( $themeoo_view );

		$the_post  = get_post( $post );
		$is_single = is_singular( $the_post->post_type );   // @phpstan-ignore-line
		$has_thumb = has_post_thumbnail( $the_post );

		do_action( 'themeoo_' . $themeoo_view . '_before_feature_image', $is_single, $has_thumb );

		if ( $has_thumb ) {
			$_attr  = [
				'alt'             => get_the_title( $the_post ), // @phpstan-ignore-line
				'link'            => true,
				'link_classes'    => '',
				'wrapper'         => true,
				'wrapper_classes' => 'post-image effect slide-top',
				'extra_classes'   => '',
				'lazy_loading'    => true,
			];
			$attr   = wp_parse_args( $attr, $_attr );
			$format = '%s';
			$lazy   = $attr['lazy_loading'];

			// Permalink.
			if ( $attr['link'] ) {
				$format = '<a href="' . get_the_permalink( $the_post ) . '">%s</a>'; // @phpstan-ignore-line
			}

			// Post Image Wrapper.
			if ( $attr['wrapper'] ) {

				if ( ! empty( $attr['extra_classes'] ) ) {
					$attr['wrapper_classes'] .= ' ' . trim( $attr['extra_classes'] );
				}

				if ( 'medium' === $themeoo_layout ) {
					$attr['wrapper_classes'] .= ' medium-left';
				}

				$wrap_attrs = $attr['wrapper_classes'] . ' ' . ( $is_single ? 'single-featured' : 'loop-featured' );
				$wrap_attrs = 'class="' . esc_attr( $attr['wrapper_classes'] ) . '"';
				$wrap_attrs = $wrap_attrs . ( $is_single ? ' style="' . themeoo_featured_image_width( $themeoo_view, $the_post ) . '"' : '' );
				$wrap_attrs = str_replace( [ '%' ], '%%', $wrap_attrs );
				$format     = '<div ' . $wrap_attrs . '>' . $format . '</div>';
			}

			unset(
				$attr['link'],
				$attr['wrapper'],
				$attr['link_classes'],
				$attr['extra_classes'],
				$attr['wrapper_classes']
			);

			if ( ! $lazy ) {
				add_filter( 'themeoo_lazyload_post_thumbnail', '__return_false' );
			}

			// Print the thumbnail.
			printf( $format, get_the_post_thumbnail( $the_post, $size, $attr ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

			if ( ! $lazy ) {
				remove_filter( 'themeoo_lazyload_post_thumbnail', '__return_false' );
			}
		}

		do_action( 'themeoo_' . $themeoo_view . '_after_feature_image', $is_single, $has_thumb );
	}
}

if ( ! function_exists( 'themeoo_edit_post_link' ) ) {
	/**
	 * Display Post Title.
	 *
	 * @return void
	 */
	function themeoo_edit_post_link() {
		edit_post_link(
			'<i class="ti-pencil-alt" aria-hidden="true"></i> ' . esc_html__( 'Edit', 'ayyash' ),
			'<span class="edit-link">',
			'</span>'
		);
	}
}

if ( ! function_exists( 'themeoo_link_pages' ) ) {
	/**
	 * The formatted output of a list of pages.
	 *
	 * @param string|array $args Optional. Array or string of default arguments.
	 *
	 * @see wp_link_pages() for detaild arguments.
	 *
	 * @return string
	 */
	function themeoo_link_pages( $args = '' ) {
		$defaults = array(
			'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'ayyash' ),
			'after'  => '</div>',
		);

		$parsed_args = wp_parse_args( $args, $defaults );

		return wp_link_pages( $parsed_args );
	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_audio' ) ) {
	/**
	 * Output Audio Player for post-format-audio
	 *
	 * @param string $layout Layout.
	 * @param WP_Post|null|int $post Current post.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_audio( $layout = '', $post = null ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		$type    = get_post_meta( $post->ID, 'themeoo_audio_source', true );
		$source  = get_post_meta( $post->ID, 'themeoo_audio_' . $type, true );
		$mime    = 'hosted' === $type ? get_post_mime_type( $source['id'] ) : false;
		$content = get_the_content( null, false, $post );

		if ( 'embedded' === $type && ! empty( $source ) ) {
			/**
			 * @var string|false $found
			 */
			$found = themeoo_render_embedded( $source, false );
			if ( $found ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php echo $found; // phpcs:ignore WordPress.Security.EscapeOutput ?>
				</div>
				<?php
			}
		} elseif ( 'hosted' === $type && ! empty( $source ) && $mime ) {
			$found = true;
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<audio class="player" controls>
					<source src="<?php echo esc_url( $source['url'] ); ?>" type="<?php echo esc_attr( $mime ); ?>">
				</audio>
			</div>
			<?php
		} else {
			if ( has_block( 'core/embed', $content ) ) {
				$found = themeoo_get_first_instance_of_block( 'core/embed', $content );
			} elseif ( has_block( 'core/audio', $content ) ) {
				$found = themeoo_get_first_instance_of_block( 'core/audio', $content );
			} else {
				$found = themeoo_get_first_instance_of_block( 'core-embed/*', $content );
			}

			if ( ! $found ) {
				// fallback for Non-Gutenberg Users.
				if ( preg_match_all( '/(\[audio.+(?:\.mp3|\.ogg).*\])/m', $content, $matches ) ) {
					$found = do_shortcode( $matches[0][0] );
				} elseif ( preg_match_all( '/(\[playlist.*\])/m', $content, $matches ) ) {
					$found = do_shortcode( $matches[0][0] );
				} else {
					// check pre historic (classic) editor link based embed
					$embedded_contents = get_media_embedded_in_content( apply_filters( 'the_content', $content ) ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound,WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
					if ( ! empty( $embedded_contents ) ) {
						$found = wp_kses(
							$embedded_contents[0],
							[
								'iframe' => [
									'title'           => [],
									'width'           => [],
									'height'          => [],
									'src'             => [],
									'frameborder'     => [],
									'loading'         => [],
									'allow'           => [],
									'allowfullscreen' => [],
								],
							]
						);
					}
				}
			}

			if ( $found ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php echo $found; // phpcs:ignore WordPress.Security.EscapeOutput ?>
				</div>
				<?php
			}
		}

		if ( ! $found ) {
			?>
			<div class="alert alert-warning">
				<strong><?php esc_html_e( 'Oops! Something went wrong.', 'ayyash' ); ?></strong>
				<?php esc_html_e( 'No audio source detected.', 'ayyash' ); ?>
			</div>
			<?php
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}
	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_gallery' ) ) {
	/**
	 * Output Gallery Carousel for post-format-gallery
	 *
	 * @param WP_Post|null|int $post Current post.
	 * @param string $layout Layout.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_gallery( $post = null, $layout = '' ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		$gallery   = get_post_meta( $post->ID, 'themeoo_gallery', true );
		$gallery   = wp_parse_id_list( $gallery );
		$slider_id = 'blog-gallery-slider' . $post->ID;
		if ( ! empty( $gallery ) ) {
			?>
			<div id="<?php echo esc_attr( $slider_id ); ?>" <?php themeoo_get_post_format_classes( $layout ); ?>>
				<!-- Wrapper for slides -->
				<div class="carousel-inner">
					<?php foreach ( $gallery as $idx => $slide ) { ?>
						<div class="carousel-item <?php echo ! $idx ? 'active' : ''; ?>">
							<?php echo wp_get_attachment_image( $slide, 'themeoo-gallery' ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
						</div>
					<?php } ?>
				</div>
				<!-- Controls -->
				<a class="carousel-control left carousel-left" href="#<?php echo esc_attr( $slider_id ); ?>" aria-label="<?php esc_attr_e( 'Previous Slide', 'ayyash' ); ?>" data-slide="prev">
					<i class="ti-angle-left" aria-hidden="true"></i>
				</a>
				<a class="carousel-control right carousel-right" href="#<?php echo esc_attr( $slider_id ); ?>" aria-label="<?php esc_attr_e( 'Next Slide', 'ayyash' ); ?>" data-slide="next">
					<i class="ti-angle-right" aria-hidden="true"></i>
				</a>
			</div>
			<?php
		} else {
			$content = get_the_content( null, false, $post );
			if ( has_block( 'core/gallery', $content ) ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php themeoo_print_first_instance_of_block( 'core/gallery', $content ); ?>
				</div>
				<?php
			} else {
				/**
				 * @var array $gallery
				 */
				$gallery   = get_post_gallery( $post->ID, false );
				$image_alt = sprintf(
					/* translators: 1: Post title, 2. Image Number. */
					__( '%1$s Gallery Image %2$d', 'ayyash' ),
					get_the_title( $post ),
					'#1' // @phpstan-ignore-line
				);
				if ( ! empty( $gallery ) && isset( $gallery['src'] ) && is_array( $gallery['src'] ) && ! empty( $gallery['src'] ) ) {
					?>
					<div id="<?php echo esc_attr( $slider_id ); ?>" <?php themeoo_get_post_format_classes( $layout ); ?>>
						<!-- Wrapper for slides -->
						<div class="carousel-inner">
							<?php foreach ( $gallery['src'] as $idx => $slide ) { ?>
								<div class="carousel-item <?php echo ! $idx ? 'active' : ''; ?>">
									<img class="img-responsive" src="<?php echo esc_url( $slide ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
								</div>
							<?php } ?>
						</div>
						<!-- Controls -->
						<a class="carousel-control left carousel-left" href="#<?php echo esc_attr( $slider_id ); ?>" aria-label="<?php esc_attr_e( 'Previous Slide', 'ayyash' ); ?>" data-slide="prev">
							<i class="ti-angle-left" aria-hidden="true"></i>
						</a>
						<a class="carousel-control right carousel-right" href="#<?php echo esc_attr( $slider_id ); ?>" aria-label="<?php esc_attr_e( 'Next Slide', 'ayyash' ); ?>" data-slide="next">
							<i class="ti-angle-right" aria-hidden="true"></i>
						</a>
					</div>
					<?php
				}
			}
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}
	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_image' ) ) {
	/**
	 * Output Post Image for post-format-image
	 *
	 * @param string $layout Layout.
	 * @param WP_Post|null|int $post Current post.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_image( $layout = '', $post = null ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		if ( has_post_thumbnail( $post ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<?php themeoo_the_post_thumbnail( 'blog-' . $layout, [ 'wrapper' => false ], $post ); ?>
			</div>
			<?php
		} else {
			$content = get_the_content( null, false, $post );
			if ( ! post_password_required( $post ) && ! is_attachment( $post->ID ) && has_block( 'core/image', $content ) ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php themeoo_print_first_instance_of_block( 'core/image', $content ); ?>
				</div>
				<?php
			} else {
				$image = get_media_embedded_in_content( apply_filters( 'the_content', $content ), array( 'image' ) ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound,WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
				if ( ! empty( $image ) ) {
					?>
					<div <?php themeoo_get_post_format_classes( $layout ); ?>>
						<?php
						echo wp_kses(
							$image[0],
							[
								'img' => [
									'width'           => [],
									'height'          => [],
									'src'             => [],
									'alt'             => [],
									'frameborder'     => [],
									'allowfullscreen' => [],
								],
							]
						);
						?>
					</div>
					<?php
				}
			}
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}
	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_link' ) ) {
	/**
	 * Output Link for post-format-link
	 *
	 * @param string $layout layout.
	 * @param WP_Post|null|int $post Current post.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_link( $layout = '', $post = null ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		$link = get_post_meta( $post->ID, 'themeoo_link_url', true );
		if ( ! empty( $link ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<div class="entry-content">
					<a href="<?php echo esc_url( $link ); ?>" target="_blank"><?php echo esc_html( $link ); ?></a>
				</div>
			</div>
			<?php
		} elseif ( has_block( 'core/paragraph' ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<?php themeoo_print_first_instance_of_block( 'core/paragraph' ); ?>
			</div>
			<?php
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}
	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_quote' ) ) {
	/**
	 * Output Quote for post-format-quote
	 *
	 * @param string $layout Layout.
	 * @param WP_Post|null|int $post Current post.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_quote( $layout = '', $post = null ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		$content = get_the_content( null, false, $post );
		$quote   = get_post_meta( $post->ID, 'themeoo_quote_text', true );
		$author  = get_post_meta( $post->ID, 'themeoo_quote_author', true );

		if ( ! empty( $quote ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<div class="entry-content">
					<blockquote>
						<p><?php echo esc_html( $quote ); ?></p>
						<?php if ( $author ) { ?>
						<small><?php echo esc_html( $author ); ?></small>
						<?php } ?>
					</blockquote>
				</div>
			</div>
			<?php
		} elseif ( has_block( 'core/quote', $content ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<br>
				<?php themeoo_print_first_instance_of_block( 'core/quote', $content ); ?>
			</div>
			<?php
		} elseif ( has_block( 'core/pullquote', $content ) ) {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<br>
				<?php themeoo_print_first_instance_of_block( 'core/pullquote', $content ); ?>
			</div>
			<?php
		} else {
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?>>
				<br>
				<?php echo apply_filters( 'the_excerpt', get_the_excerpt( $post ) ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound,WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound,WordPress.Security.EscapeOutput ?>
			</div>
			<?php
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

	}
}

if ( ! function_exists( 'themeoo_post_format_get_post_video' ) ) {
	/**
	 * Output Video Player for post-format-video
	 *
	 * @param string $layout Content layout.
	 * @param WP_Post|null|int $post Current post.
	 *
	 * @return void
	 */
	function themeoo_post_format_get_post_video( $layout = '', $post = null ) {
		$post = get_post( $post );
		if ( ! $post ) {
			return;
		}

		if ( ! $layout ) {
			$layout = themeoo_get_content_layout();
		}

		if ( 'medium' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}

		$content  = get_the_content( null, false, $post );
		$type     = get_post_meta( $post->ID, 'themeoo_video_source', true );
		$source   = get_post_meta( $post->ID, 'themeoo_video_' . $type, true );
		$duration = get_post_meta( $post->ID, 'themeoo_video_durations', true );
		$mime     = 'hosted' === $type && isset( $source['id'] ) ? get_post_mime_type( $source['id'] ) : false;

		if ( 'embedded' === $type && ! empty( $source ) ) {
			/**
			 * @var string|false $found
			 */
			$found = themeoo_render_embedded( $source, false );
			if ( $found ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php echo $found; // phpcs:ignore WordPress.Security.EscapeOutput ?>
				</div>
				<?php
			}
		} elseif ( 'hosted' === $type && ! empty( $source ) && $mime ) {
			$found = true;
			?>
			<div <?php themeoo_get_post_format_classes( $layout ); ?> >
				<video class="player" controls data-plyr-config='{ "duration": "<?php echo esc_attr( $duration ); ?>" }'>
					<source src="<?php echo esc_url( $source['url'] ); ?>" type="<?php echo esc_attr( $mime ); ?>">
				</video>
			</div>
			<?php
		} else {
			if ( has_block( 'core/embed', $content ) ) {
				$found = themeoo_get_first_instance_of_block( 'core/embed', $content );
			} elseif ( has_block( 'core/video', $content ) ) {
				$found = themeoo_get_first_instance_of_block( 'core/video', $content );
			} else {
				$found = themeoo_get_first_instance_of_block( 'core-embed/*', $content );
			}

			if ( ! $found ) {
				// fallback for Non-Gutenberg Users.
				if ( preg_match_all( '/(\[video.+(?:\.mp4|\.ogv|\.webem|\.mkv).*\])/m', $content, $matches ) ) {
					$found = do_shortcode( $matches[0][0] );
				} elseif ( preg_match_all( '/(\[playlist.*\])/m', $content, $matches ) ) {
					$found = do_shortcode( $matches[0][0] );
				} else {
					// check pre historic (classic) editor link based embed
					$embedded_contents = get_media_embedded_in_content( apply_filters( 'the_content', $content ) ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound,WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
					if ( ! empty( $embedded_contents ) ) {
						$found = wp_kses(
							$embedded_contents[0],
							[
								'iframe' => [
									'title'           => [],
									'width'           => [],
									'height'          => [],
									'src'             => [],
									'frameborder'     => [],
									'loading'         => [],
									'allow'           => [],
									'allowfullscreen' => [],
								],
							]
						);
					}
				}
			}

			if ( $found ) {
				?>
				<div <?php themeoo_get_post_format_classes( $layout ); ?>>
					<?php echo $found; // phpcs:ignore WordPress.Security.EscapeOutput ?>
				</div>
				<?php
			}
		}

		if ( ! $found ) {
			?>
			<div class="alert alert-warning">
				<strong><?php esc_html_e( 'Oops! Video Source Not Found', 'ayyash' ); ?></strong>
				<?php esc_html_e( 'Seems You did not selected any video or source type in your post area', 'ayyash' ); ?>
			</div>
			<?php
		}

		if ( 'grid' === $layout ) {
			get_template_part( 'partials/content', 'sticky' );
		}
	}
}
